..
    Copyright (C) 2019 Esteban J. G. Gabancho.

    Flask-SSO-SAML is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 0.1.0 (released 2019-04-19)

- Initial public release.
